@@ -2,4 +2,4 @@
 EXCLUSIONS=(operator.yaml) hack/deploy-setup.sh ${NAMESPACE}
 source hack/env.sh
 # operator-sdk up local --namespace ${NAMESPACE}
-operator-sdk up local --namespace ${NAMESPACE}
+operator-sdk run --local --namespace ${NAMESPACE}
